/*
  es-ES.h - Tasmota localization for Spanish (International Spanish valid for all latinamerica)

  Copyright (C) 2021  Adrian Scillato

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _LANGUAGE_ES_ES_H_
#define _LANGUAGE_ES_ES_H_

/*************************** ATTENTION *******************************\
 *
 * Due to memory constraints only UTF-8 is supported.
 * To save code space keep text as short as possible.
 * Time and Date provided by SDK can not be localized (yet).
 * Use online command StateText to translate ON, OFF, HOLD and TOGGLE.
 * Use online command Prefix to translate cmnd, stat and tele.
 *
 * Updated until v9.5.0.9
\*********************************************************************/

#define LANGUAGE_MODULE_NAME         // Enable to display "Module Generic" (ie Spanish), Disable to display "Generic Module" (ie English)

#define LANGUAGE_LCID 1034
// HTML (ISO 639-1) Language Code
#define D_HTML_LANGUAGE "es"

// "2017-03-07T11:08:02" - ISO8601:2004
#define D_YEAR_MONTH_SEPARATOR "-"
#define D_MONTH_DAY_SEPARATOR "-"
#define D_DATE_TIME_SEPARATOR "T"
#define D_HOUR_MINUTE_SEPARATOR ":"
#define D_MINUTE_SECOND_SEPARATOR ":"

#define D_DAY3LIST "DomLunMarMieJueVieSab"
#define D_MONTH3LIST "EneFebMarAbrMayJunJulAgoSepOctNovDic"

// Non JSON decimal separator
#define D_DECIMAL_SEPARATOR ","

// Common
#define D_ABSOLUTE_HUMIDITY "Abs Humidity"
#define D_ADMIN "Admin"
#define D_AIR_QUALITY "Calidad del Aire"
#define D_AP "AP"                    // Access Point
#define D_AS "como"
#define D_AUTO "AUTO"
#define D_BATT "Bat"                // Short for Battery
#define D_BATTERY_CHARGE "Charge"   // Battery charge in %
#define D_BLINK "Blink"
#define D_BLINKOFF "BlinkOff"
#define D_BOOT_COUNT "Conteo Reinicios"
#define D_BRIGHTLIGHT "Brillante"
#define D_BSSID "BSSId"
#define D_BUTTON "Botón"
#define D_BY "por"                    // Written by me
#define D_BYTES "Bytes"
#define D_CELSIUS "Celsius"
#define D_CHANNEL "Canal"
#define D_CO2 "CO2"
#define D_CODE "código"                // Button code
#define D_COLDLIGHT "Fría"
#define D_COMMAND "Comando"
#define D_CONNECTED "Conectado"
#define D_CORS_DOMAIN "Sitio WEB para CORS"
#define D_COUNT "Conteo"
#define D_COUNTER "Contador"
#define D_CT_POWER "CT Power"
#define D_CURRENT "Corriente"          // As in Voltage and Current
#define D_CURRENT_NEUTRAL "Current Neutral"
#define D_DATA "Datos"
#define D_DARKLIGHT "Oscuro"
#define D_DEBUG "Debug"
#define D_DEWPOINT "Punto de Rocío"
#define D_DISABLED "Deshabilitado"
#define D_MOVING_DISTANCE "Moving Distance"
#define D_STATIC_DISTANCE "Static Distance"
#define D_DETECT_DISTANCE "Detect Distance"
#define D_DISTANCE "Distancia"
#define D_DNS_SERVER "Servidor DNS"
#define D_DO "Oxígeno Disuelto"
#define D_DONE "Listo"
#define D_DST_TIME "DST"
#define D_EC "EC"
#define D_ECO2 "eCO₂"
#define D_EMULATION "Emulación"
#define D_ENABLED "Habilitado"
#define D_ERASE "Borrar"
#define D_ERROR "Error"
#define D_FAHRENHEIT "Fahrenheit"
#define D_FAILED "Falló"
#define D_FALLBACK "Fallback"
#define D_FALLBACK_TOPIC "FallbackTopic"
#define D_FALSE "Falso"
#define D_FILE "Archivo"
#define D_FILE_SYSTEM_SIZE "File System Size"
#define D_FLOW_RATE "Caudal"
#define D_FRAGMENTATION "frag."      // Lower case abbreviated version of fragmentation used in "memory fragmentation"
#define D_FRAME_RATE "Frame rate"
#define D_FREE_MEMORY "Memoria Libre"
#define D_PSR_MAX_MEMORY "Memoria PS-RAM"
#define D_PSR_FREE_MEMORY "Memoria PS-RAM libre"
#define D_FREQUENCY "Frecuencia"
#define D_GAS "Gas"
#define D_GATEWAY "Gateway"
#define D_GROUP "Grupo"
#define D_HOST "Host"
#define D_HALL_EFFECT "Efecto Hall"
#define D_HOSTNAME "Hostname"
#define D_HUMIDITY "Humedad"
#define D_ILLUMINANCE "Luminancia"
#define D_IMMEDIATE "inmediato"      // Button immediate
#define D_INDEX "Índice"
#define D_INFO "Información"
#define D_INFRARED "Infrarrojo"
#define D_INITIALIZED "Inicializado"
#define D_IP_ADDRESS "Dirección IP"
#define D_LIGHT "Luz"
#define D_LWT "LWT"
#define D_LQI "LQI"                  // Zigbee Link Quality Index
#define D_MODULE "Módulo"
#define D_MOISTURE "Humedad del Suelo"
#define D_MQTT "MQTT"
#define D_MULTI_PRESS "multi-press"
#define D_NOISE "Ruido"
#define D_NONE "Ninguno"
#define D_NOX "NOx"
#define D_O2 "Oxygen"
#define D_OFF "Apagado"
#define D_OFFLINE "Offline"
#define D_OK "Ok"
#define D_ON "Encendido"
#define D_ONLINE "Online"
#define D_ORP "ORP"
#define D_PASSWORD "Clave"
#define D_PH "pH"
#define D_MQ "MQ"
#define D_PARTITION "Partition"      // As in flash and firmware partition
#define D_PORT "Puerto"
#define D_POWER_FACTOR "Factor de Potencia"
#define D_POWERUSAGE "Potencia"
#define D_POWERUSAGE_ACTIVE "Potencia Activa"
#define D_POWERUSAGE_APPARENT "Potencia Aparente"
#define D_POWERUSAGE_REACTIVE "Potencia Reactiva"
#define D_PRESSURE "Presión"
#define D_PRESSUREATSEALEVEL "Presión al nivel del mar"
#define D_PROGRAM_FLASH_SIZE "Tamaño de Flash de Programa"
#define D_PROGRAM_SIZE "Tamaño Programa"
#define D_PROJECT "Proyecto"
#define D_RAIN "Lluvia"
#define D_RANGE "Rango"
#define D_RECEIVED "Recibido"
#define D_RESTART "Reiniciar"
#define D_RESTARTING "Reiniciando"
#define D_RESTART_REASON "Causa Reinicio"
#define D_RESTORE "Restauración"
#define D_RETAINED "Grabado"
#define D_RULE "Regla"
#define D_SAVE "Grabar"
#define D_SENSOR "Sensor"
#define D_SSID "SSId"
#define D_START "Iniciar"
#define D_STD_TIME "STD"
#define D_STOP "Detener"
#define D_SUBNET_MASK "Máscara Subred"
#define D_SUBSCRIBE_TO "Suscribir a"
#define D_UNSUBSCRIBE_FROM "Desuscribirse de"
#define D_SUCCESSFUL "Exitosa"
#define D_SUNRISE "Salida del Sol"
#define D_SUNSET "Puesta del Sol"
#define D_TEMPERATURE "Temperatura"
#define D_TO "a"
#define D_TOGGLE "Conmutar"
#define D_TOPIC "Topic"
#define D_TOTAL_USAGE "Total Usado"
#define D_TRANSMIT "Transmitir"
#define D_TRUE "Verdadero"
#define D_TVOC "TVOC"
#define D_UPGRADE "Actualización"
#define D_UPLOAD "Carga"
#define D_UPTIME "Tiempo Encendido"
#define D_USED "used"
#define D_USER "Usuario"
#define D_UTC_TIME "UTC"
#define D_UV_INDEX "Índice UV"
#define D_UV_INDEX_1 "Bajo"
#define D_UV_INDEX_2 "Medio"
#define D_UV_INDEX_3 "Alto"
#define D_UV_INDEX_4 "Peligroso"
#define D_UV_INDEX_5 "Quemaduras 1 a 2 grad"
#define D_UV_INDEX_6 "Quemaduras 3 grad"
#define D_UV_INDEX_7 "Fuera de Rango"
#define D_UV_LEVEL "Nivel UV"
#define D_UV_POWER "UV Power"
#define D_VERSION "Versión"
#define D_VOC "VOC"
#define D_VOLTAGE "Tensión"
#define D_VOLUME "Volumen"
#define D_WEIGHT "Peso"
#define D_WARMLIGHT "Cálida"
#define D_WEB_SERVER "Servidor Web"
#define D_SOC "Estado de Carga"
#define D_SOH "Estado de Salud"

// tasmota.ino
#define D_WARNING_MINIMAL_VERSION "Cuidado, esta versión no guarda los cambios"
#define D_LEVEL_10 "level 1-0"
#define D_LEVEL_01 "level 0-1"
#define D_SERIAL_LOGGING_DISABLED "Log serial deshabilitado"
#define D_SYSLOG_LOGGING_REENABLED "Syslog re-habilitado"

#define D_SET_BAUDRATE_TO "Baudrate a"
#define D_RECEIVED_TOPIC "Topic Recibido"
#define D_DATA_SIZE "Tamaño de Datos"
#define D_ANALOG_INPUT "Entrada Analógica"

// support.ino
#define D_OSWATCH "osWatch"
#define D_BLOCKED_LOOP "Ciclo Bloqueado"
#define D_WPS_FAILED_WITH_STATUS "WPSconfig FALLÓ con estado"
#define D_ACTIVE_FOR_3_MINUTES "activo por 3 minutos"
#define D_FAILED_TO_START "falló inicio"
#define D_PATCH_ISSUE_2186 "Patch issue 2186"
#define D_CONNECTING_TO_AP "Connectando a AP"
#define D_IN_MODE "en modo"
#define D_CONNECT_FAILED_NO_IP_ADDRESS "Falló Conexión, Dirección IP no recibida"
#define D_CONNECT_FAILED_AP_NOT_REACHED "Falló Conexión, AP no pudo ser contactado"
#define D_CONNECT_FAILED_WRONG_PASSWORD "Falló Conexión"
#define D_CONNECT_FAILED_AP_TIMEOUT "Falló Conexión, timeout de AP"
#define D_ATTEMPTING_CONNECTION "Intentando conectar..."
#define D_CHECKING_CONNECTION "Probando conexión..."
#define D_QUERY_DONE "Consulta lista. Servicio MQTT encontrado"
#define D_MQTT_SERVICE_FOUND "Servicio MQTT encontrado en"
#define D_FOUND_AT "encontrado en"
#define D_SYSLOG_HOST_NOT_FOUND "Syslog Host no encontrado"

// settings.ino
#define D_SAVED_TO_FLASH_AT "Grabado a la flash en"
#define D_LOADED_FROM_FLASH_AT "Cargado desde flash en"
#define D_USE_DEFAULTS "Usar valores por defecto"
#define D_ERASED_SECTOR "Sector borrado"

// xdrv_02_webserver.ino
#define D_NOSCRIPT "Habilitar JavaScript para usar Tasmota"
#define D_SAFEBOOT "SAFEBOOT"
#define D_MINIMAL_FIRMWARE_PLEASE_UPGRADE "Firmware MÍNIMO<br>actualice por favor"
#define D_WEBSERVER_ACTIVE_ON "Servidor web activo en"
#define D_WITH_IP_ADDRESS "con dirección IP"
#define D_WEBSERVER_STOPPED "Servidor web detenido"
#define D_FILE_NOT_FOUND "Archivo No Encontrado"
#define D_REDIRECTED "Redireccionado al portal captivo"
#define D_WIFIMANAGER_SET_ACCESSPOINT_AND_STATION "Wifimanager como AccessPoint y Estación"
#define D_WIFIMANAGER_SET_ACCESSPOINT "Wifimanager como AccessPoint"
#define D_TRYING_TO_CONNECT "Intentado conectar dispositivo a la red"

#define D_RESTART_IN "Reinicio en"
#define D_SECONDS "segundos"
#define D_DEVICE_WILL_RESTART "El dispositivo se reiniciará en unos segundos"
#define D_BUTTON_TOGGLE "Alternar ON/OFF"
#define D_CONFIGURATION "Configuración"
#define D_INFORMATION "Información"
#define D_FIRMWARE_UPGRADE "Actualizar Firmware"
#define D_MANAGEMENT "Consolas"
#define D_CONSOLE "Consola"
#define D_CONFIRM_RESTART "Confirmar Reinicio"

#define D_CONFIGURE_MODULE "Configuración del Módulo"
#define D_CONFIGURE_WIFI "Configuración WiFi"
#define D_CONFIGURE_MQTT "Configuración MQTT"
#define D_CONFIGURE_DOMOTICZ "Configuración Domoticz"
#define D_CONFIGURE_LOGGING "Configuración Logging"
#define D_CONFIGURE_OTHER "Configuración Extra"
#define D_CONFIRM_RESET_CONFIGURATION "Confirmar Reset Configuración"
#define D_RESET_CONFIGURATION "Reset de Configuración"
#define D_BACKUP_CONFIGURATION "Backup de Configuración"
#define D_RESTORE_CONFIGURATION "Restaurar Configuración"
#define D_MAIN_MENU "Menú Principal"

#define D_MODULE_PARAMETERS "Parámetros del módulo"
#define D_MODULE_TYPE "Tipo de módulo"
#define D_PULLUP_ENABLE "Botón/Llave sin pull-up"
#define D_ADC "ADC"
#define D_GPIO "GPIO"
#define D_SERIAL_IN "Serial In"
#define D_SERIAL_OUT "Serial Out"

#define D_WIFI_PARAMETERS "Parámetros Wifi"
#define D_SCAN_FOR_WIFI_NETWORKS "Buscar redes wifi"
#define D_SCAN_DONE "Busqueda finalizada"
#define D_NO_NETWORKS_FOUND "Ninguna red encontrada"
#define D_REFRESH_TO_SCAN_AGAIN "Recargar página para buscar nuevamente"
#define D_DUPLICATE_ACCESSPOINT "AccessPoint duplicado"
#define D_SKIPPING_LOW_QUALITY "Ignorado por baja calidad"
#define D_RSSI "RSSI"
#define D_WEP "WEP"
#define D_WPA_PSK "WPA PSK"
#define D_WPA2_PSK "WPA2 PSK"
#define D_AP1_SSID "Red WiFi"
#define D_AP1_SSID_HELP "Escriba o Seleccione su Red WiFi"
#define D_AP2_SSID "Red WiFi Alternativa"
#define D_AP2_SSID_HELP "Escriba el nombre de la Red WiFi Alternativa"
#define D_AP_PASSWORD "Clave WiFi"
#define D_AP_PASSWORD_HELP "Escriba la clave de WiFi"
#define D_SELECT_YOUR_WIFI_NETWORK "Seleccione su Red WiFi"
#define D_SHOW_MORE_WIFI_NETWORKS "Buscar todas las Redes WiFi"
#define D_SHOW_MORE_OPTIONS "Mas Opciones"
#define D_CHECK_CREDENTIALS "Por favor, revise la clave"
#define D_SUCCESSFUL_WIFI_CONNECTION "Conexión WiFi Existosa"
#define D_NOW_YOU_CAN_CLOSE_THIS_WINDOW "Ahora puede cerrar esta ventana"
#define D_REDIRECTING_TO_NEW_IP "Redireccionando a la nueva dirección IP"

#define D_MQTT_PARAMETERS "Parámetros MQTT"
#define D_CLIENT "Cliente"
#define D_FULL_TOPIC "Full Topic"

#define D_LOGGING_PARAMETERS "Parámetros Logging"
#define D_SERIAL_LOG_LEVEL "Nivel de log por Serial"
#define D_MQTT_LOG_LEVEL "Nivel de log por Mqtt"
#define D_WEB_LOG_LEVEL "Nivel de log por Web"
#define D_SYS_LOG_LEVEL "Nivel de log por Syslog"
#define D_MORE_DEBUG "Más Debug"
#define D_SYSLOG_HOST "Host del Syslog"
#define D_SYSLOG_PORT "Puerto del Syslog"
#define D_TELEMETRY_PERIOD "Período de Telemetría"

#define D_OTHER_PARAMETERS "Otros parámetros"
#define D_TEMPLATE "Plantilla"
#define D_ACTIVATE "Activar"
#define D_DEVICE_NAME "Nombre de Dispositivo"
#define D_WEB_ADMIN_PASSWORD "Clave Administrador Web"
#define D_MQTT_ENABLE "Habilitar MQTT"
#define D_MQTT_TLS_ENABLE "MQTT TLS"
#define D_HTTP_API "HTTP API"
#define D_HTTP_API_ENABLE "Habilitar HTTP API"
#define D_FRIENDLY_NAME "Nombre Amigable"
#define D_BELKIN_WEMO "Belkin WeMo"
#define D_HUE_BRIDGE "Hue Bridge"
#define D_SINGLE_DEVICE "dispositivo simple"
#define D_MULTI_DEVICE "dispositivo múltiple"

#define D_CONFIGURE_TEMPLATE "Configurar Plantilla"
#define D_TEMPLATE_PARAMETERS "Parámetros de Plantilla"
#define D_TEMPLATE_NAME "Nombre"
#define D_BASE_TYPE "Basada en"
#define D_TEMPLATE_FLAGS "Opciones"

#define D_SAVE_CONFIGURATION "Grabar configuración"
#define D_CONFIGURATION_SAVED "Configuración grabada"
#define D_CONFIGURATION_RESET "Configuración restablecida"

#define D_PROGRAM_VERSION "Versión del Programa"
#define D_BUILD_DATE_AND_TIME "Fecha y Hora de Compilación"
#define D_CORE_AND_SDK_VERSION "Versión Core/SDK"
#define D_FLASH_WRITE_COUNT "Contador de escritura en Flash"
#define D_MAC_ADDRESS "Dirección MAC"
#define D_MQTT_HOST "Host MQTT"
#define D_MQTT_PORT "Puerto MQTT"
#define D_MQTT_CLIENT "Cliente MQTT"
#define D_MQTT_USER "Usuario MQTT"
#define D_MQTT_TOPIC "Topic MQTT"
#define D_MQTT_GROUP_TOPIC "Group Topic MQTT"
#define D_MQTT_FULL_TOPIC "Full Topic MQTT"
#define D_MQTT_NO_RETAIN "MQTT No Retain"
#define D_MDNS_DISCOVERY "mDNS Discovery"
#define D_MDNS_ADVERTISE "mDNS Advertise"
#define D_ESP_CHIP_ID "ESP Chip Id"
#define D_FLASH_CHIP_ID "Flash Chip Id"
#define D_FLASH_CHIP_SIZE "Tamaño Flash"
#define D_FREE_PROGRAM_SPACE "Memoria de Programa Libre"

#define D_UPGRADE_BY_WEBSERVER "Actualizar por servidor web"
#define D_OTA_URL "OTA Url"
#define D_START_UPGRADE "Comenzar actualización"
#define D_UPGRADE_BY_FILE_UPLOAD "Actualizar cargando archivo bin"
#define D_UPLOAD_FACTORY "Switching to safeboot partition"
#define D_UPLOAD_STARTED "Cargando archivo"
#define D_UPGRADE_STARTED "Actualización iniciada"
#define D_UPLOAD_DONE "Carga finalizada"
#define D_UPLOAD_TRANSFER "Upload transfer"
#define D_TRANSFER_STARTED "Transfer started"
#define D_UPLOAD_ERR_1 "Ningún archivo seleccionado"
#define D_UPLOAD_ERR_2 "Espacio insuficiente"
#define D_UPLOAD_ERR_3 "Invalid file signature"
#define D_UPLOAD_ERR_4 "El tamaño de la memoria de programa es mayor que la de la flash"
#define D_UPLOAD_ERR_5 "Error de comparación del buffer de carga"
#define D_UPLOAD_ERR_6 "Carga fallida. Habilitar logging 3"
#define D_UPLOAD_ERR_7 "Carga cancelada"
#define D_UPLOAD_ERR_8 "Archivo no válido"
#define D_UPLOAD_ERR_9 "Archivo muy grande"
#define D_UPLOAD_ERR_10 "No inició chip RF"
#define D_UPLOAD_ERR_11 "No se pudo borrar en el chip RF"
#define D_UPLOAD_ERR_12 "No se puedo escribir en el chip RF"
#define D_UPLOAD_ERR_13 "No se pudo decodificar firmware RF"
#define D_UPLOAD_ERR_14 "No compatible"
#define D_UPLOAD_ERROR_CODE "Código de error de carga"

#define D_ENTER_COMMAND "Ingresar comando"
#define D_ENABLE_WEBLOG_FOR_RESPONSE "Habilitar weblog 2 si desea respuesta"
#define D_NEED_USER_AND_PASSWORD "Se necesita user=<username>&password=<password>"

// xdrv_01_mqtt.ino
#define D_FINGERPRINT "Verificar TLS fingerprint..."
#define D_TLS_CONNECT_FAILED_TO "Falló Conexión TLS a"
#define D_RETRY_IN "Reintentando"
#define D_VERIFIED "Verificado Fingerprint"
#define D_INSECURE "Conexión insegura por Fingerprint inválido"
#define D_CONNECT_FAILED_TO "Falló Conexión a"

// xplg_wemohue.ino
#define D_MULTICAST_DISABLED "Multicast deshabilitado"
#define D_MULTICAST_REJOINED "Multicast (re)conectado"
#define D_MULTICAST_JOIN_FAILED "Conexión Multicast fallida"
#define D_FAILED_TO_SEND_RESPONSE "Falla al enviar respuesta"

#define D_WEMO "WeMo"
#define D_WEMO_BASIC_EVENT "Evento base de WeMo"
#define D_WEMO_EVENT_SERVICE "Evento de servicio de WeMo"
#define D_WEMO_META_SERVICE "Meta Servicio de WeMo"
#define D_WEMO_SETUP "Configuración de WeMo"
#define D_RESPONSE_SENT "Respuesta enviada"

#define D_HUE "Hue"
#define D_HUE_BRIDGE_SETUP "Configuración Hue"
#define D_HUE_API_NOT_IMPLEMENTED "API de Hue no implementada"
#define D_HUE_API "Hue API"
#define D_HUE_POST_ARGS "Hue POST args"
#define D_3_RESPONSE_PACKETS_SENT "3 paquetes de respuesta enviados"

// xdrv_07_domoticz.ino
#define D_DOMOTICZ_PARAMETERS "Parámetros Domoticz"
#define D_DOMOTICZ_IDX "Idx"
#define D_DOMOTICZ_KEY_IDX "Key idx"
#define D_DOMOTICZ_SWITCH_IDX "Switch idx"
#define D_DOMOTICZ_SENSOR_IDX "Sensor idx"
#define D_DOMOTICZ_TEMP "Temp"
#define D_DOMOTICZ_TEMP_HUM "Temp,Hum"
#define D_DOMOTICZ_TEMP_HUM_BARO "Temp,Hum,Baro"
#define D_DOMOTICZ_POWER_ENERGY "Potencia,Energía"
#define D_DOMOTICZ_ILLUMINANCE "Luminancia"
#define D_DOMOTICZ_COUNT "Contador/PM1"
#define D_DOMOTICZ_VOLTAGE "Voltaje/PM2,5"
#define D_DOMOTICZ_CURRENT "Corriente/PM10"
#define D_DOMOTICZ_AIRQUALITY "Calidad del Aire"
#define D_DOMOTICZ_P1_SMART_METER "Medidor Inteligente P1"
#define D_DOMOTICZ_UPDATE_TIMER "Intervalo de refresco"

// xdrv_09_timers.ino
#define D_CONFIGURE_TIMER "Configuración Temporizadores"
#define D_TIMER_PARAMETERS "Parámetros de Temporizadores"
#define D_TIMER_ENABLE "Habilitar Temporizadores"
#define D_TIMER_ARM "Activo"
#define D_TIMER_TIME "Hora"
#define D_TIMER_DAYS "Días"
#define D_TIMER_REPEAT "Repetir"
#define D_TIMER_OUTPUT "Salida"
#define D_TIMER_ACTION "Estado"

// xdrv_10_knx.ino
#define D_CONFIGURE_KNX "Configuración de KNX"
#define D_KNX_PARAMETERS "Parámetros de KNX"
#define D_KNX_GENERAL_CONFIG "General"
#define D_KNX_PHYSICAL_ADDRESS "Dirección Física"
#define D_KNX_PHYSICAL_ADDRESS_NOTE "( Debe ser única en la red KNX )"
#define D_KNX_ENABLE "Habilitar KNX"
#define D_KNX_GROUP_ADDRESS_TO_WRITE "Datos a Enviar a las Direcciones de Grupo"
#define D_ADD "Agregar"
#define D_DELETE "Eliminar"
#define D_REPLY "Responder"
#define D_KNX_GROUP_ADDRESS_TO_READ "Direcciones de Grupo para Recibir Datos"
#define D_RECEIVED_FROM "Recibido desde"
#define D_KNX_COMMAND_WRITE "Escribir"
#define D_KNX_COMMAND_READ "Leer"
#define D_KNX_COMMAND_OTHER "Otro"
#define D_SENT_TO "enviada a"
#define D_KNX_WARNING "La dirección de grupo ( 0 / 0 / 0 ) está reservada y no puede ser utilizada."
#define D_KNX_ENHANCEMENT "Mejora de Comunicación"
#define D_KNX_TX_SLOT "KNX TX"
#define D_KNX_RX_SLOT "KNX RX"
#define D_KNX_TX_SCENE "KNX ESCENA TX"
#define D_KNX_RX_SCENE "KNX ESCENA RX"

// xdrv_23_zigbee
#define D_ZIGBEE_PERMITJOIN_ACTIVE "Dispositivos permitidos a unirse"
#define D_ZIGBEE_MAPPING_TITLE "Mapeo de Tasmota Zigbee"
#define D_ZIGBEE_NOT_STARTED "Zigbee no iniciado"
#define D_ZIGBEE_MAPPING_IN_PROGRESS_SEC "Mapeo en progreso (%d s. restantes)"
#define D_ZIGBEE_MAPPING_NOT_PRESENT "Sin mapeo"
#define D_ZIGBEE_MAP_REFRESH "Actualizar Mapa Zigbee"
#define D_ZIGBEE_MAP "Mapa Zigbee"
#define D_ZIGBEE_PERMITJOIN "Permitir unirse a Zigbee"
#define D_ZIGBEE_GENERATE_KEY "Generando una clave aleatoria de red Zigbee"
#define D_ZIGBEE_UNKNOWN_DEVICE "Dispositivo desconocido"
#define D_ZIGBEE_UNKNOWN_ATTRIBUTE "Atributo desconocido"
#define D_ZIGBEE_UNKNOWN_ENDPOINT "Unknown endpoint"
#define D_ZIGBEE_INVALID_PARAM "Parámetro inválido"
#define D_ZIGBEE_MISSING_PARAM "Parámetros faltantes"
#define D_ZIGBEE_UNKNWON_ATTRIBUTE "Nombre de atributo desconocido (ignorado): %s"
#define D_ZIGBEE_TOO_MANY_CLUSTERS "No mas de un id de cluster por comando"
#define D_ZIGBEE_CONFLICTING_ENDPOINTS "Conflicting destination endpoints"
#define D_ZIGBEE_WRONG_DELIMITER "Delimitador incorrecto para payload"
#define D_ZIGBEE_UNRECOGNIZED_COMMAND "Comando zigbee no reconocido: %s"
#define D_ZIGBEE_TOO_MANY_COMMANDS "Solo un comando es permitido (%d)"
#define D_ZIGBEE_NO_ATTRIBUTE "No hay atributos en la lista"
#define D_ZIGBEE_UNSUPPORTED_ATTRIBUTE_TYPE "Atributo no soportado"
#define D_ZIGBEE_JSON_REQUIRED "La configuración debe ser en JSON"
#define D_ZIGBEE_RESET_1_OR_2 "1 o 2 para resetear"
#define D_ZIGBEE_EEPROM_FOUND_AT_ADDRESS "Encontrada EEPROM de ZBBridge en"
#define D_ZIGBEE_RANDOMIZING_ZBCONFIG "Configurando parámetros Zigbee de forma aleatoria. Usar 'ZbConfig' para revisarlos."

// xdrv_89_dali.ino
#define D_SENSOR_DALI_RX                  "Dali RX"
#define D_SENSOR_DALI_TX                  "Dali TX"
#define D_CONFIGURE_DALI                  "Config DALI"

// xdrv_03_energy.ino
#define D_ENERGY_TODAY "Energía Hoy"
#define D_ENERGY_YESTERDAY "Energía Ayer"
#define D_ENERGY_TOTAL "Energía Total"

// xdrv_27_shutter.ino
#define D_OPEN "Abrir"
#define D_CLOSE "Cerrar"
#define D_DOMOTICZ_SHUTTER "Cortina"

// xdrv_28_pcf8574.ino
#define D_CONFIGURE_PCF8574 "Configurar PCF8574"
#define D_PCF8574_PARAMETERS "Parámetros de PCF8574"
#define D_INVERT_PORTS "Invertir Puertos"
#define D_DEVICE "Dispositivo"
#define D_DEVICE_INPUT "Entrada"
#define D_DEVICE_OUTPUT "Salida"

// xsns_05_ds18b20.ino
#define D_SENSOR_BUSY "Sensor ocupado"
#define D_SENSOR_CRC_ERROR "Error CRC del Sensor"
#define D_SENSORS_FOUND "Sensores encontrados"

// xsns_06_dht.ino
#define D_TIMEOUT_WAITING_FOR "Espera de timeout por"
#define D_START_SIGNAL_LOW "iniciar señal baja"
#define D_START_SIGNAL_HIGH "iniciar señal alta"
#define D_PULSE "pulso"
#define D_CHECKSUM_FAILURE "Falló Checksum"

// xsns_07_sht1x.ino
#define D_SENSOR_DID_NOT_ACK_COMMAND "Sensor no ha enviado el comando ACK"
#define D_SHT1X_FOUND "SHT1X encontrado"

// xsns_18_pms5003.ino
#define D_STANDARD_CONCENTRATION "CF-1 PM"     // Standard Particle CF-1 Particle Matter
#define D_ENVIRONMENTAL_CONCENTRATION "PM"     // Environmetal Particle Matter
#define D_PARTICALS_BEYOND "Partículas"

// xsns_27_apds9960.ino
#define D_GESTURE "Gesto"
#define D_COLOR_RED "Rojo"
#define D_COLOR_GREEN "Verde"
#define D_COLOR_BLUE "Azul"
#define D_CCT "CCT"
#define D_PROXIMITY "Proximidad"

// xsns_32_mpu6050.ino
#define D_AX_AXIS "Acel. Eje X"
#define D_AY_AXIS "Acel. Eje Y"
#define D_AZ_AXIS "Acel. Eje Z"
#define D_GX_AXIS "Girós. Eje X"
#define D_GY_AXIS "Girós. Eje Y"
#define D_GZ_AXIS "Girós. Eje Z"

// xsns_33_QMC5883L.ino
#define D_MX "Induction X-Axis"
#define D_MY "Induction Y-Axis"
#define D_MZ "Induction Z-Axis"
#define D_MAGNETICFLD "Magnetic Induction"

// xsns_34_hx711.ino
#define D_HX_CAL_REMOVE "Remover Peso"
#define D_HX_CAL_REFERENCE "Poner Peso de Referencia"
#define D_HX_CAL_DONE "Calibrado"
#define D_HX_CAL_FAIL "Falló Calibración"
#define D_RESET_HX711 "Restablecer Escala"
#define D_CONFIGURE_HX711 "Configurar Escala"
#define D_HX711_PARAMETERS "Parámetros de Escala"
#define D_ITEM_WEIGHT "Peso"
#define D_REFERENCE_WEIGHT "Peso de Referencia"
#define D_CALIBRATE "Calibrar"
#define D_CALIBRATION "Calibración"

//xsns_35_tx20.ino
#define D_TX20_WIND_DIRECTION "Dirección del Viento"
#define D_TX20_WIND_SPEED "Vel. del Viento"
#define D_TX20_WIND_SPEED_MIN "Vel. Min. del Viento"
#define D_TX20_WIND_SPEED_MAX "Vel. Max. del Viento"
#define D_TX20_NORTH "N"
#define D_TX20_EAST "E"
#define D_TX20_SOUTH "S"
#define D_TX20_WEST "O"

// xsns_53_sml.ino
#define D_TPWRIN "Energía Total-Entrada"
#define D_TPWRIN0 "Energía Total-Entrada T0"
#define D_TPWRIN1 "Energía Total-Entrada T1"
#define D_TPWROUT "Energía Total-Salida"
#define D_TPWRCURR "Potencia-En/Sal"
#define D_TPWRCURR1 "Potencia-Entr p1"
#define D_TPWRCURR2 "Potencia-Entr p2"
#define D_TPWRCURR3 "Potencia-Entr p3"
#define D_Strom_L1 "Corriente L1"
#define D_Strom_L2 "Corriente L2"
#define D_Strom_L3 "Corriente L3"
#define D_Spannung_L1 "Voltaje L1"
#define D_Spannung_L2 "Voltaje L2"
#define D_Spannung_L3 "Voltaje L3"
#define D_METERNR "Número de Medidor"
#define D_METERSID "ID de Servicio"
#define D_GasIN "Contador"
#define D_H2oIN "Contador"
#define D_StL1L2L3 "Corriente L1+L2+L3"
#define D_SpL1L2L3 "Voltaje L1+L2+L3/3"

// xsns_86_tfminiplus.ino
#define D_SIGNALSTRENGTH "Señal"
#define D_CHIPTEMPERATURE "Temperatura del Chip"

// tasmota_template.h - keep them as short as possible to be able to fit them in GUI drop down box
#define D_SENSOR_NONE          "Ninguno"
#define D_SENSOR_USER          "Por Usuario"
#define D_SENSOR_OPTION        "Opción"
#define D_SENSOR_DHT11         "DHT11"
#define D_SENSOR_AM2301        "AM2301"
#define D_SENSOR_SI7021        "SI7021"
#define D_SENSOR_MS01          "MS01"
#define D_SENSOR_DS18X20       "DS18x20"
#define D_SENSOR_I2C_SCL       "I2C SCL"
#define D_SENSOR_I2C_SDA       "I2C SDA"
#define D_SENSOR_I2S_MCLK      "I2S MCLK"
#define D_SENSOR_I2S_BCLK      "I2S BCLK"
#define D_SENSOR_I2S_WS_IN     "I2S BCLK IN"
#define D_SENSOR_I2S_WS        "I2S WS"
#define D_SENSOR_I2S_BCLK_IN   "I2S WS IN"
#define D_SENSOR_I2S_DIN       "I2S DIN"
#define D_SENSOR_I2S_DOUT      "I2S DOUT"
#define D_SENSOR_WS2812        "WS2812"
#define D_SENSOR_DFR562        "MP3 Player"
#define D_SENSOR_DFR562_BUSY   "MP3 Busy"
#define D_SENSOR_IRSEND        "IR Tx"
#define D_SENSOR_SWITCH        "Llave"      // Suffix "1"
#define D_SENSOR_BUTTON        "Botón"      // Suffix "1"
#define D_SENSOR_RELAY         "Relé"       // Suffix "1i"
#define D_SENSOR_LED           "Led"        // Suffix "1i"
#define D_SENSOR_LED_LINK      "LedLink"    // Suffix "i"
#define D_SENSOR_PWM           "PWM"        // Suffix "1"
#define D_SENSOR_COUNTER       "Contador"   // Suffix "1"
#define D_SENSOR_INTERRUPT     "Interrupt"
#define D_SENSOR_INPUT         "Entrada"
#define D_SENSOR_IRRECV        "IR Rx"
#define D_SENSOR_MHZ_RX        "MHZ Rx"
#define D_SENSOR_MHZ_TX        "MHZ Tx"
#define D_SENSOR_PZEM004_RX    "PZEM004 Rx"
#define D_SENSOR_PZEM016_RX    "PZEM016 Rx"
#define D_SENSOR_PZEM017_RX    "PZEM017 Rx"
#define D_SENSOR_PZEM0XX_TX    "PZEM0XX Tx"
#define D_SENSOR_SAIR_RX       "SAir Rx"
#define D_SENSOR_SAIR_TX       "SAir Tx"
#define D_SENSOR_SPI_CS        "SPI CS"
#define D_SENSOR_SPI_DC        "SPI DC"
#define D_SENSOR_SPI_MISO      "SPI MISO"
#define D_SENSOR_SPI_MOSI      "SPI MOSI"
#define D_SENSOR_SPI_CLK       "SPI CLK"
#define D_SENSOR_SDIO_CMD      "SDIO CMD"
#define D_SENSOR_SDIO_CLK      "SDIO CLK"
#define D_SENSOR_SDIO_D0       "SDIO D0"
#define D_SENSOR_SDIO_D1       "SDIO D1"
#define D_SENSOR_SDIO_D2       "SDIO D2"
#define D_SENSOR_SDIO_D3       "SDIO D3"
#define D_SENSOR_BACKLIGHT    "Backlight"
#define D_SENSOR_PMS5003_TX    "PMS5003 Tx"
#define D_SENSOR_PMS5003_RX    "PMS5003 Rx"
#define D_SENSOR_SDS0X1_RX     "SDS0X1 Rx"
#define D_SENSOR_SDS0X1_TX     "SDS0X1 Tx"
#define D_SENSOR_HPMA_RX       "HPMA Rx"
#define D_SENSOR_HPMA_TX       "HPMA Tx"
#define D_SENSOR_SBR_RX        "SerBr Rx"
#define D_SENSOR_SBR_TX        "SerBr Tx"
#define D_SENSOR_MBR_TX        "ModBr Tx"
#define D_SENSOR_MBR_RX        "ModBr Rx"
#define D_SENSOR_MBR_TX_ENA    "ModBr Tx Ena"
#define D_SENSOR_SR04_TRIG     "SR04 Tri/TX"
#define D_SENSOR_SR04_ECHO     "SR04 Ech/RX"
#define D_SENSOR_NRG_MBS_TX    "NrgMbs Tx"
#define D_SENSOR_NRG_MBS_RX    "NrgMbs Rx"
#define D_SENSOR_NRG_MBS_TX_ENA  "NrgMbs Tx Ena"
#define D_SENSOR_SDM72_TX      "SDM72 Tx"
#define D_SENSOR_SDM72_RX      "SDM72 Rx"
#define D_SENSOR_SDM120_TX     "SDMx20 Tx"
#define D_SENSOR_SDM120_RX     "SDMx20 Rx"
#define D_SENSOR_SDM230_TX     "SDM230 Tx"
#define D_SENSOR_SDM230_RX     "SDM230 Rx"
#define D_SENSOR_SDM630_TX     "SDM630 Tx"
#define D_SENSOR_SDM630_RX     "SDM630 Rx"
#define D_SENSOR_WE517_TX      "WE517 Tx"
#define D_SENSOR_WE517_RX      "WE517 Rx"
#define D_SENSOR_LD2410_TX     "LD2410 Tx"
#define D_SENSOR_LD2410_RX     "LD2410 Rx"
#define D_GPIO_TM1621_CS       "TM1621 CS"
#define D_GPIO_TM1621_WR       "TM1621 WR"
#define D_GPIO_TM1621_RD       "TM1621 RD"
#define D_GPIO_TM1621_DAT      "TM1621 DAT"
#define D_SENSOR_TM1637_CLK    "TM1637 CLK"
#define D_SENSOR_TM1637_DIO    "TM1637 DIO"
#define D_SENSOR_TM1638_CLK    "TM1638 CLK"
#define D_SENSOR_TM1638_DIO    "TM1638 DIO"
#define D_SENSOR_TM1638_STB    "TM1638 STB"
#define D_SENSOR_MAX7219_DIN   "MAX7219 DIN"
#define D_SENSOR_MAX7219_CS    "MAX7219 CS"
#define D_SENSOR_MAX7219_CLK   "MAX7219 CLK"
#define D_SENSOR_HX711_SCK     "HX711 SCK"
#define D_SENSOR_HX711_DAT     "HX711 DAT"
#define D_SENSOR_FTC532        "FTC532"
#define D_SENSOR_BS814_CLK     "BS814 CLK"
#define D_SENSOR_BS814_DAT     "BS814 DAT"
#define D_SENSOR_TX2X_TX       "TX2x"
#define D_SENSOR_RFSEND        "RFSend"
#define D_SENSOR_RFRECV        "RFrecv"
#define D_SENSOR_TUYA_TX       "Tuya Tx"
#define D_SENSOR_TUYA_RX       "Tuya Rx"
#define D_SENSOR_MGC3130_XFER  "MGC3130 Xfr"
#define D_SENSOR_MGC3130_RESET "MGC3130 Rst"
#define D_SENSOR_SSPI_MISO     "SSPI MISO"
#define D_SENSOR_SSPI_MOSI     "SSPI MOSI"
#define D_SENSOR_SSPI_SCLK     "SSPI SCLK"
#define D_SENSOR_SSPI_CS       "SSPI CS"
#define D_SENSOR_SSPI_DC       "SSPI DC"
#define D_SENSOR_RF_SENSOR     "RF Sensor"
#define D_SENSOR_AZ_RX         "AZ Rx"
#define D_SENSOR_AZ_TX         "AZ Tx"
#define D_SENSOR_MAX31855_CS   "MX31855 CS"
#define D_SENSOR_MAX31855_CLK  "MX31855 CLK"
#define D_SENSOR_MAX31855_DO   "MX31855 DO"
#define D_SENSOR_MAX31865_CS   "MX31865 CS"
#define D_SENSOR_NRG_SEL       "HLWBL SEL"  // Suffix "i"
#define D_SENSOR_NRG_CF1       "HLWBL CF1"
#define D_SENSOR_HLW_CF        "HLW8012 CF"
#define D_SENSOR_HJL_CF        "BL0937 CF"
#define D_SENSOR_MCP39F5_TX    "MCP39F5 Tx"
#define D_SENSOR_MCP39F5_RX    "MCP39F5 Rx"
#define D_SENSOR_MCP39F5_RST   "MCP39F5 Rst"
#define D_SENSOR_CSE7761_TX    "CSE7761 Tx"
#define D_SENSOR_CSE7761_RX    "CSE7761 Rx"
#define D_SENSOR_CSE7766_TX    "CSE7766 Tx"
#define D_SENSOR_CSE7766_RX    "CSE7766 Rx"
#define D_SENSOR_BL0939_RX     "BL0939 Rx"
#define D_SENSOR_BL0942_RX     "BL0942 Rx"
#define D_SENSOR_HM330X_SET    "HM330X SET"
#define D_SENSOR_PN532_TX      "PN532 Tx"
#define D_SENSOR_PN532_RX      "PN532 Rx"
#define D_SENSOR_SM16716_CLK   "SM16716 CLK"
#define D_SENSOR_SM16716_DAT   "SM16716 DAT"
#define D_SENSOR_SM16716_POWER "SM16716 PWR"
#define D_SENSOR_P9813_CLK     "P9813 Clk"
#define D_SENSOR_P9813_DAT     "P9813 Dat"
#define D_SENSOR_MY92X1_DI     "MY92x1 DI"
#define D_SENSOR_MY92X1_DCKI   "MY92x1 DCKI"
#define D_SENSOR_ARIRFRCV      "ALux IrRcv"
#define D_SENSOR_ARIRFSEL      "ALux IrSel"
#define D_SENSOR_TXD           "Serial Tx"
#define D_SENSOR_RXD           "Serial Rx"
#define D_SENSOR_ROTARY        "Rotary"     // Suffix "1A"
#define D_SENSOR_HRE_CLOCK     "HRE Clock"
#define D_SENSOR_HRE_DATA      "HRE Data"
#define D_SENSOR_ADE7880_IRQ   "ADE7880 IRQ"
#define D_SENSOR_ADE7953_IRQ   "ADE7953 IRQ"
#define D_SENSOR_ADE7953_RST   "ADE7953 RST"
#define D_SENSOR_ADE7953_CS    "ADE7953 CS"
#define D_SENSOR_BUZZER        "Buzzer"
#define D_SENSOR_DISP_RESET    "Display Rst"
#define D_SENSOR_ZIGBEE_TXD    "Zigbee Tx"
#define D_SENSOR_ZIGBEE_RXD    "Zigbee Rx"
#define D_SENSOR_ZIGBEE_RST    "Zigbee Rst"
#define D_SENSOR_SOLAXX1_TX    "SolaxX1 Tx"
#define D_SENSOR_SOLAXX1_RX    "SolaxX1 Rx"
#define D_SENSOR_SOLAXX1_RTS   "SolaxX1 RTS"
#define D_SENSOR_IBEACON_TX    "iBeacon TX"
#define D_SENSOR_IBEACON_RX    "iBeacon RX"
#define D_SENSOR_RDM6300_RX    "RDM6300 RX"
#define D_SENSOR_CC1101_CS     "CC1101 CS"
#define D_SENSOR_A4988_DIR     "A4988 DIR"
#define D_SENSOR_A4988_STP     "A4988 STP"
#define D_SENSOR_A4988_ENA     "A4988 ENA"
#define D_SENSOR_A4988_MS1     "A4988 MS1"
#define D_SENSOR_OUTPUT_HI     "Fijo a ON"
#define D_SENSOR_OUTPUT_LO     "Fijo a OFF"
#define D_SENSOR_AS608_TX      "AS608 Tx"
#define D_SENSOR_AS608_RX      "AS608 Rx"
#define D_SENSOR_GM861_TX      "GM861 Tx"
#define D_SENSOR_GM861_RX      "GM861 Rx"
#define D_SENSOR_DDS2382_TX    "DDS238-2 Tx"
#define D_SENSOR_DDS2382_RX    "DDS238-2 Rx"
#define D_SENSOR_DDSU666_TX    "DDSU666 Tx"
#define D_SENSOR_DDSU666_RX    "DDSU666 Rx"
#define D_SENSOR_SM2135_CLK    "SM2135 Clk"
#define D_SENSOR_SM2135_DAT    "SM2135 Dat"
#define D_SENSOR_SM2335_CLK    "SM2335 Clk"
#define D_SENSOR_SM2335_DAT    "SM2335 Dat"
#define D_SENSOR_BP1658CJ_CLK  "BP1658CJ Clk"
#define D_SENSOR_BP1658CJ_DAT  "BP1658CJ Dat"
#define D_SENSOR_BP5758D_CLK    "BP5758D Clk"
#define D_SENSOR_BP5758D_DAT    "BP5758D Dat"
#define D_SENSOR_DEEPSLEEP     "DeepSleep"
#define D_SENSOR_EXS_ENABLE    "EXS Enable"
#define D_SENSOR_CLIENT_TX     "Client TX"
#define D_SENSOR_CLIENT_RX     "Client RX"
#define D_SENSOR_CLIENT_RESET  "Client RST"
#define D_SENSOR_GPS_RX        "GPS RX"
#define D_SENSOR_GPS_TX        "GPS TX"
#define D_SENSOR_HM10_RX       "HM10 RX"
#define D_SENSOR_HM10_TX       "HM10 TX"
#define D_SENSOR_LE01MR_RX     "LE-01MR Rx"
#define D_SENSOR_LE01MR_TX     "LE-01MR Tx"
#define D_SENSOR_BL0940_RX     "BL0940 Rx"
#define D_SENSOR_CC1101_GDO0   "CC1101 GDO0"
#define D_SENSOR_CC1101_GDO2   "CC1101 GDO2"
#define D_SENSOR_HRXL_RX       "HRXL Rx"
#define D_SENSOR_DYP_RX        "DYP Rx"
#define D_SENSOR_ELECTRIQ_MOODL "MOODL Tx"
#define D_SENSOR_AS3935        "AS3935"
#define D_SENSOR_WINDMETER_SPEED "WindMeter Spd"
#define D_SENSOR_TELEINFO_RX   "TInfo Rx"
#define D_SENSOR_TELEINFO_ENABLE "TInfo EN"
#define D_SENSOR_LMT01_PULSE   "LMT01 Pulse"
#define D_SENSOR_ADC_INPUT     "ADC Entrada"
#define D_SENSOR_ADC_TEMP      "ADC Temp"
#define D_SENSOR_ADC_LIGHT     "ADC Luz"
#define D_SENSOR_ADC_BUTTON    "ADC Botón"
#define D_SENSOR_ADC_RANGE     "ADC Rango"
#define D_SENSOR_ADC_CT_POWER  "ADC CT Potencia"
#define D_SENSOR_ADC_JOYSTICK  "ADC Joystick"
#define D_SENSOR_ADC_PH        "ADC pH"
#define D_SENSOR_ADC_MQ        "ADC MQ"
#define D_GPIO_WEBCAM_PWDN     "CAM_PWDN"
#define D_GPIO_WEBCAM_RESET    "CAM_RESET"
#define D_GPIO_WEBCAM_XCLK     "CAM_XCLK"
#define D_GPIO_WEBCAM_SIOD     "CAM_SIOD"
#define D_GPIO_WEBCAM_SIOC     "CAM_SIOC"
#define D_GPIO_WEBCAM_DATA     "CAM_DATA"
#define D_GPIO_WEBCAM_VSYNC    "CAM_VSYNC"
#define D_GPIO_WEBCAM_HREF     "CAM_HREF"
#define D_GPIO_WEBCAM_PCLK     "CAM_PCLK"
#define D_GPIO_WEBCAM_PSCLK    "CAM_PSCLK"
#define D_GPIO_WEBCAM_HSD      "CAM_HSD"
#define D_GPIO_WEBCAM_PSRCS    "CAM_PSRCS"
#define D_SENSOR_ETH_PHY_POWER "ETH POWER"
#define D_SENSOR_ETH_PHY_MDC   "ETH MDC"
#define D_SENSOR_ETH_PHY_MDIO  "ETH MDIO"
#define D_SENSOR_TCP_TXD       "TCP Tx"
#define D_SENSOR_TCP_RXD       "TCP Rx"
#define D_SENSOR_IEM3000_TX    "iEM3000 TX"
#define D_SENSOR_IEM3000_RX    "iEM3000 RX"
#define D_SENSOR_MIEL_HVAC_TX  "MiEl HVAC Tx"
#define D_SENSOR_MIEL_HVAC_RX  "MiEl HVAC Rx"
#define D_SENSOR_PROJECTOR_CTRL_TX  "DLP Tx"
#define D_SENSOR_PROJECTOR_CTRL_RX  "DLP Rx"
#define D_SENSOR_SHELLY_DIMMER_BOOT0 "SHD Boot 0"
#define D_SENSOR_SHELLY_DIMMER_RST_INV "SHD Reset"
#define D_SENSOR_RC522_RST     "RC522 Rst"
#define D_SENSOR_RC522_CS      "RC522 CS"
#define D_SENSOR_NRF24_CS      "NRF24 CS"
#define D_SENSOR_NRF24_DC      "NRF24 DC"
#define D_SENSOR_XPT2046_CS    "XPT2046 CS"
#define D_SENSOR_ILI9341_CS    "ILI9341 CS"
#define D_SENSOR_ILI9341_DC    "ILI9341 DC"
#define D_SENSOR_ILI9488_CS    "ILI9488 CS"
#define D_SENSOR_EPAPER29_CS   "EPaper29 CS"
#define D_SENSOR_EPAPER42_CS   "EPaper42 CS"
#define D_SENSOR_SSD1351_CS    "SSD1351 CS"
#define D_SENSOR_SSD1351_DC    "SSD1351 DC"
#define D_SENSOR_RA8876_CS     "RA8876 CS"
#define D_SENSOR_ST7789_CS     "ST7789 CS"
#define D_SENSOR_ST7789_DC     "ST7789 DC"
#define D_SENSOR_SSD1331_CS    "SSD1331 CS"
#define D_SENSOR_SSD1331_DC    "SSD1331 DC"
#define D_SENSOR_SDCARD_CS     "SDCard CS"
#define D_SENSOR_WIEGAND_D0    "Wiegand D0"
#define D_SENSOR_WIEGAND_D1    "Wiegand D1"
#define D_SENSOR_NEOPOOL_TX    "NeoPool Tx"
#define D_SENSOR_NEOPOOL_RX    "NeoPool Rx"
#define D_SENSOR_VL53LXX_XSHUT "VL53LXX XSHUT"
#define D_SENSOR_TFMINIPLUS_TX  "TFmini+ TX"
#define D_SENSOR_TFMINIPLUS_RX  "TFmini+ RX"
#define D_SENSOR_ZEROCROSS     "Cruce por cero"
#define D_SENSOR_HALLEFFECT    "HallEffect"
#define D_SENSOR_EPD_DATA      "EPD Data"
#define D_SENSOR_PCF8574_INT   "PCF8574 Int"
#define D_SENSOR_MCP23XXX_INT  "MCP23xxx Int"
#define D_SENSOR_MCP23SXX_CS   "MCP23Sxx CS"
#define D_SENSOR_MCP2515_CS    "MCP2515 CS"
#define D_SENSOR_HRG15_RX      "HRG15 Rx"
#define D_SENSOR_HRG15_TX      "HRG15 Tx"
#define D_SENSOR_VINDRIKTNING_RX "VINDRIKTNING"
#define D_SENSOR_BL6523_TX "BL6523 Tx"
#define D_SENSOR_BL6523_RX "BL6523 Rx"
#define D_SENSOR_HEARTBEAT     "Heartbeat"
#define D_SENSOR_RESET         "Reset"
#define D_GPIO_SHIFT595_SRCLK  "74x595 SRCLK"
#define D_GPIO_SHIFT595_RCLK   "74x595 RCLK"
#define D_GPIO_SHIFT595_OE     "74x595 OE"
#define D_GPIO_SHIFT595_SER    "74x595 SER"
#define D_GPIO_DINGTIAN_CLK    "Dingtian CLK"
#define D_GPIO_DINGTIAN_SDI    "Dingtian SDI"
#define D_GPIO_DINGTIAN_Q7     "Dingtian Q7"
#define D_GPIO_DINGTIAN_PL     "Dingtian PL"
#define D_GPIO_DINGTIAN_OE     "Dingtian OE"
#define D_GPIO_DINGTIAN_RCK    "Dingtian RCK"
#define D_SENSOR_CM11_TX       "CM110x TX"
#define D_SENSOR_CM11_RX       "CM110x RX"
#define D_SENSOR_FLOWRATEMETER "Flowrate"
#define D_SENSOR_ME007_TRIG    "ME007 Tri"
#define D_SENSOR_ME007_RX      "ME007 Rx"
#define D_SENSOR_TUYAMCUBR_TX  "TuyaMCUBr Tx"
#define D_SENSOR_TUYAMCUBR_RX  "TuyaMCUBr Rx"
#define D_SENSOR_BIOPDU_PZEM0XX_TX "BioPDU PZEM0XX Tx"
#define D_SENSOR_BIOPDU_PZEM016_RX "BioPDU PZEM016 Rx"
#define D_SENSOR_BIOPDU_BIT    "BioPDU Bit"
#define D_SENSOR_LOX_O2_RX     "LoxO2 RX"

// Units
#define D_UNIT_AMPERE "A"
#define D_UNIT_CELSIUS "C"
#define D_UNIT_CENTIMETER "cm"
#define D_UNIT_DEGREE "°"
#define D_UNIT_FAHRENHEIT "F"
#define D_UNIT_FPS "FPS"
#define D_UNIT_HERTZ "Hz"
#define D_UNIT_HOUR "h"
#define D_UNIT_GALLONS "gal"
#define D_UNIT_GALLONS_PER_MIN "g/m"
#define D_UNIT_GRAM_PER_CUBIC_METER "g/m³"
#define D_UNIT_INCH_MERCURY "inHg"
#define D_UNIT_INCREMENTS "inc"
#define D_UNIT_KELVIN "K"
#define D_UNIT_KILOMETER "km"
#define D_UNIT_KILOGRAM "kg"
#define D_UNIT_KILOMETER_PER_HOUR "km/h"  // or "km/h"
#define D_UNIT_KILOOHM "kΩ"
#define D_UNIT_KILOWATTHOUR "kWh"
#define D_UNIT_LITERS "L"
#define D_UNIT_LITERS_PER_MIN "L/m"
#define D_UNIT_LUX "lx"
#define D_UNIT_MICROGRAM_PER_CUBIC_METER "µg/m³"
#define D_UNIT_MICROMETER "µm"
#define D_UNIT_MICROSECOND "µs"
#define D_UNIT_MICROSIEMENS_PER_CM "µS/cm"
#define D_UNIT_MICROTESLA "µT"
#define D_UNIT_MILLIAMPERE "mA"
#define D_UNIT_MILLILITERS "ml"
#define D_UNIT_MILLIMETER "mm"
#define D_UNIT_MILLIMETER_MERCURY "mmHg"
#define D_UNIT_MILLISECOND "ms"
#define D_UNIT_MILLIVOLT "mV"
#define D_UNIT_MINUTE "Min"
#define D_UNIT_PARTS_PER_BILLION "ppb"
#define D_UNIT_PARTS_PER_DECILITER "ppd"
#define D_UNIT_PARTS_PER_MILLION "ppm"
#define D_UNIT_MILIGRAMS_PER_LITER "mg/L"
#define D_UNIT_PERCENT "%%"
#define D_UNIT_PRESSURE "hPa"
#define D_UNIT_SECOND "seg"
#define D_UNIT_SECTORS "sectores"
#define D_UNIT_VA "VA"
#define D_UNIT_VAR "VAr"
#define D_UNIT_VOLT "V"
#define D_UNIT_WATT "W"
#define D_UNIT_WATTHOUR "Wh"
#define D_UNIT_WATT_METER_QUADRAT "W/m²"
#define D_UNIT_LITER_PER_MINUTE "l/min"
#define D_UNIT_CUBICMETER_PER_HOUR "m³/h"
#define D_UNIT_CUBIC_METER "m³"

#define D_NEW_ADDRESS          "Cambiando dirección a"
#define D_OUT_OF_RANGE         "Fuera de Rango"
#define D_SENSOR_DETECTED      "detectado"

//SDM220, SDM120, SDM72, LE01MR, SDM230
#define D_EXPORT_POWER    "Pot. Exportada"
#define D_IMPORT_POWER 	  "Pot. Importada"
#define D_PHASE_ANGLE     "Ángulo de Fase"
#define D_IMPORT_ACTIVE   "P. Activa Entrante"
#define D_EXPORT_ACTIVE   "P. Activa Saliente"
#define D_IMPORT_REACTIVE "P. Reactiva Entrante"
#define D_EXPORT_REACTIVE "P. Reactiva Saliente"
#define D_TOTAL_REACTIVE  "P. Reactiva Total"
#define D_UNIT_KWARH      "kVArH"
#define D_UNIT_ANGLE      "Grados"
#define D_TOTAL_ACTIVE    "P. Total Activa"
#define D_RESETTABLE_TOTAL_ACTIVE    "P. Total Activa (RST)"

//SOLAXX1
#define D_PV1_VOLTAGE     "PV1 Voltaje"
#define D_PV1_CURRENT     "PV1 Corriente"
#define D_PV1_POWER       "PV1 Potencia"
#define D_PV2_VOLTAGE     "PV2 Voltaje"
#define D_PV2_CURRENT     "PV2 Corriente"
#define D_PV2_POWER       "PV2 Potencia"
#define D_SOLAR_POWER     "Potencia Solar"
#define D_INVERTER_POWER  "Potencia del Inversor"
#define D_STATUS          "Estado"
#define D_SOLAX_MODE_0    "En Espera"
#define D_SOLAX_MODE_1    "Revisando"
#define D_SOLAX_MODE_2    "Funcionando"
#define D_SOLAX_MODE_3    "Falla"
#define D_SOLAX_MODE_4    "Permanent Failure"  // to be translated
#define D_SOLAX_MODE_5    "Software Update"  // to be translated
#define D_SOLAX_MODE_6    "Selftest"  // to be translated
#define D_SOLAX_ERROR_0   "Sin código de Error"
#define D_SOLAX_ERROR_1   "Falla por Pérdida de Red"
#define D_SOLAX_ERROR_2   "Falla por Voltaje de Red"
#define D_SOLAX_ERROR_3   "Falla por Frecuencia de Red"
#define D_SOLAX_ERROR_4   "Falla por Voltaje en PV"
#define D_SOLAX_ERROR_5   "Falla de Aislación"
#define D_SOLAX_ERROR_6   "Falla por sobretemperatura"
#define D_SOLAX_ERROR_7   "Falla de Ventilador"
#define D_SOLAX_ERROR_8   "Falla del Dispositivo"

//xdrv_10_scripter.ino
#define D_CONFIGURE_SCRIPT     "Editar Script"
#define D_SCRIPT               "Editar Script"
#define D_SDCARD_UPLOAD        "Subir Archivo"
#define D_UFSDIR               "Directorio en Tarjeta UFS"
#define D_UPL_DONE             "Listo"
#define D_SCRIPT_CHARS_LEFT    "Caracteres disponibles"
#define D_SCRIPT_CHARS_NO_MORE "No hay mas espacio"
#define D_SCRIPT_DOWNLOAD      "Descargar"
#define D_SCRIPT_ENABLE        "Habilitar Script"
#define D_SCRIPT_UPLOAD        "Cargar"
#define D_SCRIPT_UPLOAD_FILES  "Cargar Archivos"

//xdrv_50_filesystem.ino
#define D_MANAGE_FILE_SYSTEM   "Explorar Archivos"
#define D_FS_SIZE              "Tamaño"
#define D_FS_FREE              "Libre"
#define D_NEW_FILE             "Nuevo.txt"
#define D_CREATE_NEW_FILE      "Crear un archivo nuevo"
#define D_EDIT_FILE            "Editar Archivo"
#define D_CONFIRM_FILE_DEL     "Confirmar eliminación del archivo"
#define D_SHOW_HIDDEN_FILES    "Mostrar archivos ocultos"

//xsns_67_as3935.ino
#define D_AS3935_GAIN "Ganancia:"
#define D_AS3935_ENERGY "Energía:"
#define D_AS3935_DISTANCE "Distancia:"
#define D_AS3935_DISTURBER "Perturbancia:"
#define D_AS3935_VRMS "µVrms:"
#define D_AS3935_APRX "aprox.:"
#define D_AS3935_AWAY "lejos"
#define D_AS3935_LIGHT "Relámpagos"
#define D_AS3935_OUT "Relámpagos fuera de rango"
#define D_AS3935_NOT "Distancia no determinada"
#define D_AS3935_ABOVE "Relámpagos cercanos"
#define D_AS3935_NOISE "Ruido detectado"
#define D_AS3935_DISTDET "Perturbancia detectada"
#define D_AS3935_INTNOEV "Interrupción sin evento!"
#define D_AS3935_FLICKER "IRQ flicker!"
#define D_AS3935_POWEROFF "Apagado"
#define D_AS3935_NOMESS "Escuchando..."
#define D_AS3935_ON "Encendido"
#define D_AS3935_OFF "Apagado"
#define D_AS3935_INDOORS "Dentro de casa"
#define D_AS3935_OUTDOORS "Al aire libre"
#define D_AS3935_CAL_FAIL "Falló calibración"
#define D_AS3935_CAL_OK "Calibración a:"

//xsns_68_opentherm.ino
#define D_SENSOR_BOILER_OT_RX   "OpenTherm RX"
#define D_SENSOR_BOILER_OT_TX   "OpenTherm TX"

// xnrg_15_teleinfo Denky (Teleinfo)
#define D_CONTRACT        "Contratado"
#define D_POWER_LOAD      "Potencia"
#define D_CURRENT_TARIFF  "Tarifa Actual"
#define D_TARIFF          "Tarifa"
#define D_OVERLOAD        "ADPS"
#define D_MAX_POWER       "Potencia Máxima"
#define D_MAX_CURRENT     "Corriente Máxima"

// xsns_79_as608.ino
#define D_FP_ENROLL_PLACEFINGER "Colocar dedo"
#define D_FP_ENROLL_REMOVEFINGER "Retirar dedo"
#define D_FP_ENROLL_PLACESAMEFINGER "Colocar de nuevo el mismo dedo"
#define D_FP_ENROLL_RETRY "Error, reintentar"
#define D_FP_ENROLL_RESTART "Reiniciar"
#define D_FP_ENROLL_ERROR "Error"
#define D_FP_ENROLL_RESET "Resetear"
#define D_FP_ENROLL_ACTIVE "Activo"
#define D_FP_ENROLL_INACTIVE "Inactivo"
// Indexed by Adafruit_Fingerprint.h defines
#define D_FP_PACKETRECIEVEERR "Error de Comms"    // 0x01 Error when receiving data package
#define D_FP_NOFINGER ""                       // 0x02 No finger on the sensor
#define D_FP_IMAGEFAIL "Error de Imagen"         // 0x03 Failed to enroll the finger
#define D_FP_IMAGEMESS "Imagen Ilegible"       // 0x06 Failed to generate character file due to overly disorderly fingerprint image
#define D_FP_FEATUREFAIL "Huella muy pequeña" // 0x07 Failed to generate character file due to the lack of character point or small fingerprint image
#define D_FP_NOMATCH "Sin coincidencias"                // 0x08 Finger doesn't match
#define D_FP_NOTFOUND "Sin coincidencias"   // 0x09 Failed to find matching finger
#define D_FP_ENROLLMISMATCH "Sin coincidencias" // 0x0A Failed to combine the character files
#define D_FP_BADLOCATION "Localización Incorrecta"        // 0x0B Addressed PageID is beyond the finger library
#define D_FP_DBRANGEFAIL "Error de DB"      // 0x0C Error when reading template from library or invalid template
#define D_FP_UPLOADFEATUREFAIL "Error de grabado" // 0x0D Error when uploading template
#define D_FP_PACKETRESPONSEFAIL "Error de paquete" // 0x0E Module failed to receive the following data packages
#define D_FP_UPLOADFAIL "Error de subida"         // 0x0F Error when uploading image
#define D_FP_DELETEFAIL "No se pudo borrar"         // 0x10 Failed to delete the template
#define D_FP_DBCLEARFAIL "No se pudo borra la DB"      // 0x11 Failed to clear finger library
#define D_FP_PASSFAIL "Error de Clave"         // 0x13 Find whether the fingerprint passed or failed
#define D_FP_INVALIDIMAGE "Imágen inválida"      // 0x15 Failed to generate image because of lac of valid primary image
#define D_FP_FLASHERR "Error escribiendo en Flash"      // 0x18 Error when writing flash
#define D_FP_INVALIDREG "Número inválido"       // 0x1A Invalid register number
#define D_FP_ADDRCODE "Código de Dirección"           // 0x20 Address code
#define D_FP_PASSVERIFY "Clave Correcta"    // 0x21 Verify the fingerprint passed
#define D_FP_UNKNOWNERROR "Error"              // Any other error

// xsns_96_flowratemeter.ino
#define D_FLOWRATEMETER_NAME "Flowrate"
#define D_FLOWRATEMETER_AMOUNT_TODAY "Amount Today"
#define D_FLOWRATEMETER_DURATION_TODAY "Duration Today"

// xsns_83_neopool.ino
#define D_NEOPOOL_MACH_NONE               "NeoPool"           // Machine names
#define D_NEOPOOL_MACH_HIDROLIFE          "Hidrolife"
#define D_NEOPOOL_MACH_AQUASCENIC         "Aquascenic"
#define D_NEOPOOL_MACH_OXILIFE            "Oxilife"
#define D_NEOPOOL_MACH_BIONET             "Bionet"
#define D_NEOPOOL_MACH_HIDRONISER         "Hidroniser"
#define D_NEOPOOL_MACH_UVSCENIC           "UVScenic"
#define D_NEOPOOL_MACH_STATION            "Station"
#define D_NEOPOOL_MACH_BRILIX             "Brilix"
#define D_NEOPOOL_MACH_GENERIC            "Genérico"
#define D_NEOPOOL_MACH_BAYROL             "Bayrol"
#define D_NEOPOOL_MACH_HAY                "Heno"
#define D_NEOPOOL_FILTRATION_MANUAL       "Manual"            // Filtration modes
#define D_NEOPOOL_FILTRATION_AUTO         "Auto"
#define D_NEOPOOL_FILTRATION_HEATING      "Calentando"
#define D_NEOPOOL_FILTRATION_SMART        "Inteligente"
#define D_NEOPOOL_FILTRATION_INTELLIGENT  "Inteligente"
#define D_NEOPOOL_FILTRATION_BACKWASH     "Lavado"
#define D_NEOPOOL_FILTRATION_NONE         ""                  // Filtration speed level
#define D_NEOPOOL_FILTRATION_SLOW         "lento"
#define D_NEOPOOL_FILTRATION_MEDIUM       "medio"
#define D_NEOPOOL_FILTRATION_FAST         "rápido"
#define D_NEOPOOL_TYPE                    "Tipo"              // Sensor & relais names
#define D_NEOPOOL_REDOX                   "Redox"
#define D_NEOPOOL_CHLORINE                "Cloro"
#define D_NEOPOOL_CONDUCTIVITY            "Conductividad"
#define D_NEOPOOL_IONIZATION              "Ionización"
#define D_NEOPOOL_HYDROLYSIS              "Hidrólisis"
#define D_NEOPOOL_RELAY                   "Relé"
#define D_NEOPOOL_RELAY_FILTRATION        "Filtrar"        // Relay assignment
#define D_NEOPOOL_RELAY_LIGHT             "Luz"
#define D_NEOPOOL_RELAY_PH_ACID           "Bomba de Ácido"
#define D_NEOPOOL_RELAY_PH_BASE           "Bomba de Base"
#define D_NEOPOOL_RELAY_RX                "Nivel Redox"
#define D_NEOPOOL_RELAY_CL                "Bomba de Cloro"
#define D_NEOPOOL_RELAY_CD                "Conductividad"
#define D_NEOPOOL_RELAY_HEATING           "Calentando"
#define D_NEOPOOL_RELAY_UV                "UV"
#define D_NEOPOOL_RELAY_VALVE             "Valve"
#define D_NEOPOOL_RELAY_AUX               "Aux"
#define D_NEOPOOL_TIME                    "Tiempo"
#define D_NEOPOOL_FILT_MODE               "Modo de filtrado"
#define D_NEOPOOL_CELL_RUNTIME            "Tiempo de actividad"
#define D_NEOPOOL_POLARIZATION            "Pol"               // Sensor status
#define D_NEOPOOL_PR_OFF                  "PrOff"
#define D_NEOPOOL_SETPOINT_OK             "Ok"
#define D_NEOPOOL_COVER                   "Cover"
#define D_NEOPOOL_SHOCK                   "Golpe"
#define D_NEOPOOL_STATUS_ON               "Encendido"
#define D_NEOPOOL_STATUS_OFF              "Apagado"
#define D_NEOPOOL_STATUS_WAIT             "Espera"
#define D_NEOPOOL_STATUS_TANK             "Tanque"
#define D_NEOPOOL_STATUS_FLOW             "Flujo"
#define D_NEOPOOL_LOW                     "Bajo"
#define D_NEOPOOL_FLOW1                   "FL1"
#define D_NEOPOOL_FLOW2                   "FL2"
#define D_NEOPOOL_PH_HIGH                 "muy alto"          // ph Alarms
#define D_NEOPOOL_PH_LOW                  "muy bajo"
#define D_NEOPOOL_PUMP_TIME_EXCEEDED      "tiempo de bomba excedido"

// xsns_106_gdk101.ino
#define D_AVG_RAD_DOSE                    "dosis media de radiación"
#define D_UNIT_US_H                       "µSv/h"

#endif  // _LANGUAGE_ES_ES_H_
