/*
  xdrv_111_freedsm_id.ino - FreeDSM support for Tasmota

  Tasmota:
  Copyright (C) 2021  Markus Bösling and Theo Arends

  FreeDSM:
  Copyrigth (C) 2023  Daniel Boubeta Portela
                      José Carlos Dafonte Vázquez

  University of A Coruña (UDC), Galicia, Spain
  Developed as a part of the Gaia4Sustainability (G4S) project
  <http://gaia4sustainability.eu/>.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*********************************************************************************************\
 * FreeDSM - Id management module
 *
 * Generate the id file for the FreeDSM device in the format:
 * freedsm-XXXXXX-XXXX
\*********************************************************************************************/

#ifdef ESP32
#ifdef USE_FREEDSM

#define XDRV_111 111

/*********************************************************************************************\
 * Global variables
\*********************************************************************************************/

uint8_t xdrv111_valid = 0;
char id_str[20];

#ifdef USE_WEBSERVER
const char HTTP_DRV_FREEDSM[] PROGMEM =
    "{s}Device ID{m}%s{e}"
    "{s}Firmware version{m}%s{e}";
#endif // USE_WEBSERVER

/*********************************************************************************************\
 * FreeDSM management functions
\*********************************************************************************************/

void FreeDSM_GenerateId() {
    sprintf(id_str, "%s", TasmotaGlobal.hostname);
    FILE* id_file = fopen(".id", "w");
    fprintf(id_file, id_str);
    fclose(id_file);

    xdrv111_valid = 1;
    return;
}

void FreeDSM_ShowID() {
#ifdef USE_WEBSERVER
    if (xdrv111_valid) {
        WSContentSend_PD(HTTP_DRV_FREEDSM, id_str, FREEDSM_VERSION);
    }
#endif // USE_WEBSERVER
    return;
}

/*********************************************************************************************\
 * Interface
\*********************************************************************************************/

bool Xdrv111(uint32_t function) {
    bool result = false;

    if (FUNC_INIT == function) {
        FreeDSM_GenerateId();
        
    } else if (xdrv111_valid) {
        switch (function) {

#ifdef USE_WEBSERVER
        case FUNC_WEB_SENSOR:
            FreeDSM_ShowID();
            break;
#endif // USE_WEBSERVER

        default:
            break;
        }
    }
    return result;
}

#endif // USE_FREEDSM
#endif // ESP32