/*
  xsns_111_freedsm.ino - FreeDSM support for Tasmota

  Tasmota:
  Copyright (C) 2021  Markus Bösling and Theo Arends

  FreeDSM:
  Copyrigth (C) 2024 José Carlos Dafonte Vázquez  
                     Daniel Boubeta Portela

  University of A Coruña (UDC), Galicia, Spain
  Developed as a part of the Gaia4Sustainability (G4S) project
  <http://gaia4sustainability.eu/>.

  Info custom drivers: https://github.com/phpcoder/tasmota-custom-integration

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*********************************************************************************************\
 * TSL2591 - Light Intensity
 *
 * I2C Addresses: 0x29 (low), 0x39 (float) or 0x49 (high)
 * (Used library supports address 0x29 only)
\*********************************************************************************************/

#ifdef USE_I2C
#ifdef USE_FREEDSM
#define XSNS_111 111
#define XI2C_40 40 // See I2CDEVICES.md

#define TSL2591_ADDRESS 0x29

#include <Adafruit_TSL2591.h>

/*********************************************************************************************\
 * Global variables
\*********************************************************************************************/

// TSL2591 metadata variables
Adafruit_TSL2591 tsl = Adafruit_TSL2591();
uint8_t tsl2591_type = 0;
uint8_t tsl2591_valid = 0;

// Teleperiod variables
int16_t last_minute = -1;
uint8_t reading_idx = 0;

// Arrays for the 'FREEDSM_TSL2591_SAMPLES' readings
uint16_t ir_readings[FREEDSM_TSL2591_SAMPLES] = {0};
uint16_t full_readings[FREEDSM_TSL2591_SAMPLES] = {0};
char config_sensor[2] = {0};
//float lux_readings[FREEDSM_TSL2591_SAMPLES] = {0};

// Average values to show on the web and send to Domoticz/Home Assistant
//uint16_t ir_avg = 0;
//uint16_t full_avg = 0;
//float lux_avg = 0.0;
//float mpsas = 0.0;
//float correction_factor = 0.0;

// time in UTC to send in messages
char timesensor[26] = {0};

// Definition of the readings struct, used to return the readings from the
// sensor in a single function call
struct readings {
    uint16_t ir;
    uint16_t full;
    char inttime;
    char gain;
//    uint32_t lum;
//    float lux;
};

// Special request COMMAND Sensor111
struct SPECIAL {
  int InstantReading = 0;
  char IntegrationTimeFlag = '6';
  char GainFlag = '0';
  int FlagAuto = 1;
} FreeDSMspecial;

#ifdef USE_WEBSERVER
const char HTTP_SNS_TSL2591[] PROGMEM =
    "<tr style=\"height: 15px\"><td colspan=\"2\"></td></tr>"   // Blank space between sensors
    "{s}Full Spectrum (mean){m}%s{e}"
    "{s}Infrared (mean){m}%s{e}"
    "{s}Automatic measure {m}%s{e}"
    "<tr style=\"height: 15px\"><td colspan=\"2\"></td></tr>";  // Blank space between sensors
#endif // USE_WEBSERVER

/*********************************************************************************************\
 * Utils functions
\*********************************************************************************************/

/* float Utils_GetCorrectionFactor(void) {
    float correction_factor = 0.0;
    char correction_str[FLOAT_STR_SIZE];

    // Open the correction file for reading
    FILE* file = fopen(FREEDSM_TSL2591_CORRECTION_FILE, "r");
    if (file != NULL) {
        // Read the correction factor from the file
        if (fgets(correction_str, FLOAT_STR_SIZE, file) != NULL) {
            correction_factor = strtof(correction_str, NULL);
        }
        fclose(file);
    } else {
        // Create the correction file with the default value
        file = fopen(FREEDSM_TSL2591_CORRECTION_FILE, "w");
        if (file != NULL) {
            fprintf(file, "%.1f", 0.0);
            fclose(file);
        }
    }

    return correction_factor;
}

*/

template<typename T>
void Utils_ArrayToString(T* array, uint8_t size, char* out) {
    static_assert(sizeof(T) == 0, "Unsupported type");
    return;
}

template<>
void Utils_ArrayToString<uint16_t>(uint16_t *array, uint8_t size, char* out) {
    char str[RAW_STR_SIZE];
    char str_aux[SHORT_STR_SIZE];
    strcpy(str, "[");

    for (uint8_t i = 0; i < size; i++) {
        sprintf(str_aux, "%u", array[i]);
        strcat(str, str_aux);
        if (i < size - 1) {
            strcat(str, ",");
        }
    }

    strcat(str, "]");
    strcpy(out, str);
    return;
}

template<>
void Utils_ArrayToString<float>(float *array, uint8_t size, char* out) {
    char str[RAW_STR_SIZE];
    char str_aux[LONG_STR_SIZE];
    strcpy(str, "\"[");

    for (uint8_t i = 0; i < size; i++) {
        sprintf(str_aux, "%.7f", array[i]);
        strcat(str, str_aux);
        if (i < size - 1) {
            strcat(str, ",");
        }
    }

    strcat(str, "]\"");
    strcpy(out, str);
    return;
}

uint16_t Utils_ArrayAverage(uint16_t *array, uint8_t size) {
    uint32_t sum = 0;
    for (uint8_t i = 0; i < size; i++) {
        sum += array[i];
    }
    return (uint16_t) (sum / size);
}

float Utils_ArrayAverageF(float *array, uint8_t size) {
        float sum = 0;
    for (uint8_t i = 0; i < size; i++) {
        sum += array[i];
    }
    return sum / size;
}

/* PENDING: DECIDE WITH ONE TO USE

int Utils_findClosest(uint16_t *array, int size, uint16_t ref)
{
     int smallestIndex=0;
     for(int i=0;i<size-1;i++)
     {
          if (fabs(array[i]-ref) > fabs(array[i+1]-ref)) smallestIndex=i+1;
     }
    return (smallestIndex);
}

int Utils_findMax (uint16_t *array, int size)
{
     int maxIndex=0;
     for(int i=0;i<size-1;i++)
     {
        if (array[i] < array[i+1]) maxIndex=i+1;
     }
    return (maxIndex);
}

float Utils_ComputeMPSAS(float lux, float correction_factor) {
    float mpsas = 0.0;

    if (lux <= 0) {
        // If the lux is negative, it means that the sensor is saturated,
        // so the magnitude is 0, as there is too much light
        mpsas = 0.0;
    } else {
        // Compute the magnitude using the formula in Unihedron forum:
        // http://www.unihedron.com/projects/darksky/magconv.php
        mpsas = (log10(lux / 108000) / (-0.4)) + correction_factor;
        if (mpsas > 23.0) mpsas = 23.0;
    }

    return mpsas;
}

*/

/*********************************************************************************************\
* TSL2591 management functions
\*********************************************************************************************/

void FreeDSM_Tsl2591Init(void) {
    if (I2cSetDevice(0x29)) {
        if (tsl.begin()) {
            tsl.setGain(TSL2591_GAIN_MAX);
            tsl.setTiming(TSL2591_INTEGRATIONTIME_100MS);
            tsl2591_type = 1;
            I2cSetActiveFound(TSL2591_ADDRESS, "TSL2591");
        } else {
            Serial.println("FreeDSM: TSL2591 I2C 0x29 initialising error");
            // LOG_LEVEL_NONE, LOG_LEVEL_ERROR, LOG_LEVEL_INFO, LOG_LEVEL_DEBUG, LOG_LEVEL_DEBUG_MORE
            AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: TSL2591 I2C 0x29 initialising error")); 
        }

        // Initialize the readings arrays and config (integration time and gain) array for all of them
        for (uint8_t i = 0; i < FREEDSM_TSL2591_SAMPLES; i++) {
            ir_readings[i] = 0;
            full_readings[i] = 0;
        //    lux_readings[i] = 0.0;
        }

        config_sensor[0]=FreeDSMspecial.IntegrationTimeFlag;
        config_sensor[1]=FreeDSMspecial.GainFlag;

        // PENDING: Read the sensor one time to get the first readings REMOVE??
        struct readings r = FreeDSM_Tsl2591Read();
        //ir_avg = r.ir;
        //full_avg = r.full;
        //lux_avg = r.lux;
        strcpy(timesensor, "----------T--:--:--");
        // If Berry script receives this string, no time set, it will not send data
    } else {
        Serial.println("FreeDSM: TSL2591 I2C 0x29 initialising error");
        AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: TSL2591 I2C 0x29 not found")); 
    }
}

struct readings FreeDSM_Tsl2591Read(void) {

    struct readings r;
    r.gain = FreeDSMspecial.GainFlag;
    r.inttime = FreeDSMspecial.IntegrationTimeFlag;

    if (FreeDSMspecial.GainFlag=='9') {
            tsl.setGain(TSL2591_GAIN_HIGH);
            } else {
                    tsl.setGain(TSL2591_GAIN_MAX);
                   }
    if (FreeDSMspecial.IntegrationTimeFlag=='5') {
            tsl.setTiming(TSL2591_INTEGRATIONTIME_500MS);
           } else {
                   tsl.setTiming(TSL2591_INTEGRATIONTIME_600MS);
                  }
    
    uint32_t lum = tsl.getFullLuminosity();

    uint16_t current_ir, current_full;
    //float current_lux;

    current_ir = lum >> 16;
    current_full = lum & 0xFFFF;
    //if (current_ir > current_full) { current_full = current_ir; } // PENDING: Testing...
    //current_lux = tsl.calculateLux(current_full, current_ir);
    tsl2591_valid = 1;

    // Return the readings in a struct

    r.ir = current_ir;
    r.full = current_full;
    //r.lux = current_lux;
    return r;
}

void FreeDSM_Tsl2591EverySecond(void) {
    // Get the current time in UTC and check if it is valid
    time_t now = time(nullptr);
    if (now > 0) {

        // Extract the current minute
        struct tm timeinfo;
        if (gmtime_r(&now, &timeinfo) == nullptr) {
            Serial.println("FreeDSM: Failed to get time");
            AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: Failed to get time"));   
            return;
        }
    
        int minute = timeinfo.tm_min;
        int second = timeinfo.tm_sec;

        // Check if the last minute has been initialized
        if (last_minute < 0) {
            last_minute = minute;
        } else if (((last_minute >= 0) && (last_minute != minute) && (second>50)) ||
                  (FreeDSMspecial.InstantReading == 1) || (reading_idx >= 1))
            {

            // Read the sensor ONLY ONCE (n CONSECUTIVE SAMPLES) EVERY MINUTE and store the readings in the arrays.
            // Read also if an Instant Reading is requested by command from Berry by button or console command.
            // Continue reading if an initiated sequence of readings is ongoing.

            // When the arrays are full, 

            struct readings r = FreeDSM_Tsl2591Read();
            ir_readings[reading_idx] = r.ir;
            full_readings[reading_idx] = r.full;
            //lux_readings[reading_idx] = r.lux;
            
            reading_idx += 1;

            if (reading_idx >= FREEDSM_TSL2591_SAMPLES) {

                config_sensor[0] = r.inttime;
                config_sensor[1] = r.gain;

                // If DT_LOCAL, completes the information in "2017-03-07T11:08:02-07:00" - ISO8601:2004
                // PENDING: UTC or LOCAL. Check tasmota_support/support_rtc.ino

                strcpy(timesensor, GetDateAndTime(DT_UTC).c_str());
                
                // Get the correction factor from the file. PENDING: one value, in the future many values
                //correction_factor = Utils_GetCorrectionFactor();

                // Compute the average values
                //ir_avg = Utils_ArrayAverage(ir_readings, FREEDSM_TSL2591_SAMPLES);
                //full_avg = Utils_ArrayAverage(full_readings, FREEDSM_TSL2591_SAMPLES);
                //lux_avg = Utils_ArrayAverageF(lux_readings, FREEDSM_TSL2591_SAMPLES);
                //mpsas = Utils_ComputeMPSAS(lux_avg, correction_factor);

                // Update the teleperiod variables, if instant reding, allow more than one reading period
                if (FreeDSMspecial.InstantReading == 1) {
                    FreeDSMspecial.InstantReading = 0;
                    FreeDSMspecial.FlagAuto = 0;
                } 
                else {
                      last_minute = minute;
                      FreeDSMspecial.FlagAuto = 1;
                     }

                reading_idx = 0;
            }
        }
    }
}

void FreeDSM_Tsl2591Show(bool json) {
    if (tsl2591_valid) {
        //char ir_str[SHORT_STR_SIZE];
        //char full_str[SHORT_STR_SIZE];
        //char lux_str[FLOAT_STR_SIZE];
        //char mpsas_str[FLOAT_STR_SIZE];
        //char correction_factor_str[FLOAT_STR_SIZE];

        //sprintf(ir_str, "%d", ir_avg);
        //sprintf(full_str, "%d", full_avg);
        //sprintf(lux_str, "%.7f", lux_avg);
        //sprintf(mpsas_str, "%.2f", mpsas);
        //sprintf(correction_factor_str, "%.3f", correction_factor);

        // Conversion to String to send by MQTT

        // arrays to publish, the reason they are global
        
        char auto_str[SHORT_STR_SIZE];
        char ir_readings_str[RAW_STR_SIZE];
        char full_readings_str[RAW_STR_SIZE];

        //char lux_readings_str[RAW_STR_SIZE];
        Utils_ArrayToString(ir_readings, FREEDSM_TSL2591_SAMPLES, ir_readings_str);
        Utils_ArrayToString(full_readings, FREEDSM_TSL2591_SAMPLES, full_readings_str);
//      Utils_ArrayToString(lux_readings, FREEDSM_TSL2591_SAMPLES, lux_readings_str);
        sprintf(auto_str, "%d\0", FreeDSMspecial.FlagAuto);

        if (json) {

            ResponseAppend_P(PSTR(",\"TSL2591\":{\"TimeSensor\":\"%s\",\"Auto\":%s,\"FullSpectrum\":%s,\"Infrared\":%s,\"ConfigSensor\":[%c,%c],\"VersionFw\":\"%s\"}"), 
                timesensor, auto_str, full_readings_str, ir_readings_str, config_sensor[0],config_sensor[1], FREEDSM_VERSION);
            
#ifdef USE_DOMOTICZ
            if (0 == TasmotaGlobal.tele_period) {
                DomoticzSensor(DZ_ILLUMINANCE, ir_readings[3]);
                DomoticzSensor(DZ_ILLUMINANCE, full_readings[3]);
                //DomoticzSensor(DZ_ILLUMINANCE, lux_avg); PENDING: It sends 4th value
            }
#endif // USE_DOMOTICZ

#ifdef USE_WEBSERVER
        } else {
                uint16_t ir_avg = 0;
                uint16_t full_avg = 0;
                char ir_str[SHORT_STR_SIZE];
                char full_str[SHORT_STR_SIZE];
                ir_avg = Utils_ArrayAverage(ir_readings, FREEDSM_TSL2591_SAMPLES);
                full_avg = Utils_ArrayAverage(full_readings, FREEDSM_TSL2591_SAMPLES);
                sprintf(ir_str, "%d", ir_avg);
                sprintf(full_str, "%d", full_avg);
                WSContentSend_PD(HTTP_SNS_TSL2591, full_str, ir_str, auto_str);
#endif // USE_WEBSERVER
        }

    }
}

/*********************************************************************************************\
 * Commands
 * https://tasmota.github.io/docs/Sensor-API/
\*********************************************************************************************/

bool FreeDSM_Command(void) {
  bool serviced = true;

  if (XdrvMailbox.data_len == 1) {
    char send = XdrvMailbox.data[0] & 0xDF;  // Make uppercase
    switch (send) {

            case 'I':
                    FreeDSMspecial.InstantReading = 1;
                    AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: Instant reading started"));   
                    break;
            case '5':
                    FreeDSMspecial.IntegrationTimeFlag = '5';
                    AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: Integration time 500ms each sample"));   
                    break;
            case '6':
                    FreeDSMspecial.IntegrationTimeFlag = '6';
                    AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: Integration time 600ms each sample"));   
                    break;
            case 'H':
                    FreeDSMspecial.GainFlag = '9';
                    AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: Gain high each sample"));   
                    break;
            case 'M':
                    FreeDSMspecial.GainFlag = '0';
                    AddLog(LOG_LEVEL_INFO,PSTR("FreeDSM: Gain max each sample"));   
                    break;
            default :
                    {} 
    }
    ResponseCmndDone();
  }

  return serviced;
}

/*********************************************************************************************\
 * Interface
\*********************************************************************************************/

bool Xsns111(uint32_t function) {
    if (!I2cEnabled(XI2C_40)) { return false; }
    bool result = false;
    
    if (FUNC_INIT == function) {
        FreeDSM_Tsl2591Init();

    } else if (tsl2591_type) {
        switch (function) {

            case FUNC_EVERY_SECOND:
                FreeDSM_Tsl2591EverySecond();
                break;

            case FUNC_JSON_APPEND:
                FreeDSM_Tsl2591Show(1);  // 1 means JSON format
                break;

            case FUNC_COMMAND_SENSOR:
                result = FreeDSM_Command();
                break;

            #ifdef USE_WEBSERVER
            case FUNC_WEB_SENSOR:
                FreeDSM_Tsl2591Show(0);  // 0 means HTML (web server Tasmota interface)
            break;
            #endif // USE_WEBSERVER
        }
    }
    return result;
}

#endif // USE_TSL2591
#endif // USE_I2C
