/*
  user_config_override.h - user configuration overrides my_user_config.h for Tasmota

  Tasmota:
  Copyright (C) 2021  Theo Arends

  FreeDSM:
  Copyrigth (C) 2023  Daniel Boubeta Portela
                      José Carlos Dafonte Vázquez

  University of A Coruña (UDC), Galicia, Spain
  Developed as a part of the Gaia4Sustainability (G4S) project
  <http://gaia4sustainability.eu/>.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _USER_CONFIG_OVERRIDE_H_
#define _USER_CONFIG_OVERRIDE_H_

/*********************************************************************************************\
 * Basic Configuration
\*********************************************************************************************/

#ifndef ESP32
#define ESP32
#endif

#ifdef PROJECT
#undef PROJECT
#endif
#define PROJECT "FreeDSM"

#ifdef FRIENDLY_NAME
#undef FRIENDLY_NAME
#endif
#define FRIENDLY_NAME "FreeDSM"
#define FREEDSM_VERSION "2.4"

#ifdef MODULE
#undef MODULE
#endif
#define MODULE USER_MODULE

#ifdef FALLBACK_MODULE
#undef FALLBACK_MODULE
#endif
#define FALLBACK_MODULE USER_MODULE

#ifdef USER_TEMPLATE
#undef USER_TEMPLATE
#endif

/* Info about templates in Tasmota and template command in the console
   List of codes of GPIO starting 0, 544 defines LedLink for GPIO12, led left (leds upside)
   Screen backlight, 922, fits on GPIO11 but SPI_VCC (enable with espefuse)
   Toggle ON/OFF enables BACKLIGHT SCREEN (GPIO11)
   GPIO13 is Button5 (36 up) shared with led on the right :-(
   Command: GPIO 255 shows configuration
   https://tasmota.github.io/docs/Templates/
*/

//#define USER_TEMPLATE "{\"NAME\":\"FreeDSM ESP32C3\",\"GPIO\":[4704,1,736,704,32,33,800,768,34,35,1024,992,544,36,0,0,0,0,640,608,6210,0],\"FLAG\":0,\"BASE\":18}"
#define USER_TEMPLATE "{\"NAME\":\"FreeDSM ESP32C3\",\"GPIO\":[4704,1,736,704,32,33,800,768,34,35,1024,992,544,36,0,0,0,0,640,608,6210,0],\"FLAG\":0,\"BASE\":18}"

/*  Serial data 115200 8N1 Windows-> Kitty with options Terminal->Local echo force on Keyboard->CR LR*/

#ifndef USE_WEBSERVER
#define USE_WEBSERVER
#endif

#ifndef USE_HOME_ASSISTANT
#define USE_HOME_ASSISTANT
#endif

/* https://tasmota.github.io/docs/DeepSleep/#driver-writer-executing-commands-before-entering-deepsleep
#define DEEPSLEEP_NETWORK_TIMEOUT 0 */

/*********************************************************************************************\
 * OTA Server
\*********************************************************************************************/

#ifdef OTA_URL
#undef OTA_URL
#endif
#define OTA_URL "https://gitlab.citic.udc.es/lia2-publico/g4s/-/wikis/fw/firmware.bin"

/*********************************************************************************************\
 * Telemetry Settings
\*********************************************************************************************/

#ifdef TELE_PERIOD
#undef TELE_PERIOD
#endif
#define TELE_PERIOD 60

#ifdef TELE_ON_POWER
#undef TELE_ON_POWER
#endif
#define TELE_ON_POWER false

/*********************************************************************************************\
 * Sensors and Components Settings
\*********************************************************************************************/

#ifndef USE_I2C
#define USE_I2C
#endif

#undef I2CDRIVERS_0_31
#undef I2CDRIVERS_32_63
#undef I2CDRIVERS_64_95

#define I2CDRIVERS_0_31  0x7FFFEFF7
#define I2CDRIVERS_32_63 0xFFBFFF3F
#define I2CDRIVERS_64_95 0xFFFFFFFD

#define USE_FREEDSM
#define USE_AHT2x

/*********************************************************************************************\
 * FreeDSM - TSL2591 Settings
\*********************************************************************************************/

#define FREEDSM_TSL2591_SAMPLES 6

#define RAW_STR_SIZE 80
#define LONG_STR_SIZE 15
#define FLOAT_STR_SIZE 10
#define SHORT_STR_SIZE 6

/*********************************************************************************************\
 * FreeDSM - AHT2X Settings
\*********************************************************************************************/

// ...

/*********************************************************************************************\
 * Display Settings
\*********************************************************************************************/

#define USE_SPI
#define USE_DISPLAY
#define USE_UNIVERSAL_DISPLAY

#define USE_BERRY
#define USE_LVGL
#define USE_LVGL_PNG_DECODER 

/*********************************************************************************************\
 * Additional Configuration
\*********************************************************************************************/

// [SetOption1] Disable button multipress
#ifdef KEY_DISABLE_MULTIPRESS
#undef KEY_DISABLE_MULTIPRESS
#endif
#define KEY_DISABLE_MULTIPRESS true

// [SetOption13] Enable only single press to speed up button press recognition
#ifdef KEY_ONLY_SINGLE_PRESS
#undef KEY_ONLY_SINGLE_PRESS
#endif
#define KEY_ONLY_SINGLE_PRESS true

// [SetOption36] Number of boot loops before restoring factory defaults
#ifdef BOOT_LOOP_OFFSET
#undef BOOT_LOOP_OFFSET
#endif
#define BOOT_LOOP_OFFSET 0

// [SetOption65] Disable fast power cycle detection for device reset
#ifdef APP_DISABLE_POWERCYCLE
#undef APP_DISABLE_POWERCYCLE
#endif
#define APP_DISABLE_POWERCYCLE true

// [SetOption73] Detach buttons from relays and send multi-press and hold MQTT messages instead
#ifdef MQTT_BUTTONS
#undef MQTT_BUTTONS
#endif
#define MQTT_BUTTONS true

// [PowerOnState] Power On Relay state
#ifdef APP_POWERON_STATE
#undef APP_POWERON_STATE
#endif
#define APP_POWERON_STATE POWER_ALL_ON

#define USE_RULES

#ifdef USER_BACKLOG
#undef USER_BACKLOG
#endif
#define USER_BACKLOG "SetOption135 1; DisplayModel 17; DisplayMode 0; DisplayRotate 2; Restart 1;"

#endif  // _USER_CONFIG_OVERRIDE_H_
